import { LogLevel } from '@genesislcap/foundation-logger';

/**
 * Interface for Alert Structure
 *  @public
 */
export declare interface AlertStructure {
    readonly title: string;
    readonly body: string;
    readonly logLevel?: LogLevel;
}

/**
 * Interface for Banner configuration
 * @public
 */
export declare interface Banner {
    readonly dismissingAction?: DismissingAction;
    readonly confirmingActions?: Array<ConfirmingAction>;
}

/**
 * BannerBuilder
 * @public
 * @deprecated Use showNotificationBanner instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare class BannerBuilder {
    private dismissingAction;
    private confirmingActions;
    /**
     * Add dismissing action to Banner
     * @public
     * @param dismissingAction - {@link DismissingAction}
     * @returns
     * @deprecated Use showNotificationBanner instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withDismissingAction(dismissingAction: DismissingAction): BannerBuilder;
    /**
     * Add confirming action to Banner
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     * @deprecated Use showNotificationBanner instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withConfirmingAction(confirmingAction: ConfirmingAction): BannerBuilder;
    /**
     * Build Banner
     * @public
     * @returns Banner
     * @deprecated Use showNotificationBanner instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    build(): Banner;
}

/**
 * Interface for Banner Structure
 *  @public
 */
export declare interface BannerStructure {
    readonly body: string;
    readonly logLevel?: LogLevel;
    readonly banner?: Banner;
}

/**
 * Interface for Confirming Action configuration
 * @public
 */
export declare interface ConfirmingAction {
    readonly label: String;
    readonly action: Function;
}

/**
 * Interface for Dialog configuration
 * @public
 */
export declare interface Dialog {
    readonly confirmingActions?: Array<ConfirmingAction>;
    readonly dismissingAction?: DismissingAction;
}

/**
 * DialogBuilder class
 * @public
 * @deprecated Use showNotificationDialog instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare class DialogBuilder {
    private dismissingAction;
    private confirmingActions;
    /**
     * Add dismissing action to Dialog
     * @public
     * @param dismissingAction - {@link DismissingAction}
     * @returns
     * @deprecated Use showNotificationDialog instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withDismissingAction(dismissingAction: DismissingAction): DialogBuilder;
    /**
     * Add confirming action to Dialog
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     * @deprecated Use showNotificationDialog instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withConfirmingAction(confirmingAction: ConfirmingAction): DialogBuilder;
    /**
     * Build Dialog
     * @public
     * @returns Dialog
     * @deprecated Use showNotificationDialog instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    build(): Dialog;
}

/**
 * @internal
 */
export declare type DialogElement = NotificationElement & {
    show: Function;
};

/**
 * Interface for Dialog Structure
 *  @public
 */
export declare interface DialogStructure {
    readonly title: string;
    readonly body: string;
    readonly logLevel?: LogLevel;
    readonly dialog?: Dialog;
}

/**
 * Interface for Dismissing Action configuration
 * @public
 */
export declare interface DismissingAction {
    readonly label: String;
    readonly action?: Function;
}

/**
 * Get the banner anchor to attach the banner to
 * @public
 * @param element - The element to start searching from
 * @returns
 */
export declare const getBannerAnchor: (element: any) => HTMLElement | null;

/**
 * Get banner builder instance
 * @public
 * @deprecated Use showNotificationBanner instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare const getBannerBuilder: () => BannerBuilder;

/**
 * Returns an instance of DialogBuilder
 * @public
 * @deprecated Use showNotificationDialog instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare const getDialogBuilder: () => DialogBuilder;

/**
 * Retrieves the log level from an NotificationStructure object
 * @public
 * @param details - The NotificationStructure object
 * @returns The log level or the default value (LogLevel.Debug) if not present
 */
export declare const getLoglevel: (details: NotificationStructure) => LogLevel;

/**
 * Returns a new NotificationBuilder instance
 * @public
 * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare const getNotificationBuilder: () => NotificationBuilder;

/**
 * Get/Create the error container in the DOM
 * @public
 * @param id - The id of the container
 * @param tagName - The tag name to create prefix for the design system provider
 * @returns
 */
export declare const getNotificationContainer: (id: string, tagName: String) => HTMLElement;

/**
 * Retrieves the notification details from an NotificationStructure object
 * @public
 * @param details - The NotificationStructure object
 * @returns The title and body concatenated as a string, or default values ('Error: Something went wrong') if not present
 */
export declare const getNotificationDetails: (details: NotificationStructure) => string;

/**
 * Get snackbar builder instance
 * @public
 * @deprecated Use showNotificationSnackbar instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare const getSnackbarBuilder: () => SnackbarBuilder;

/**
 * Get notification builder instance
 * @public
 * @deprecated Use showNotificationToast instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare const getToastBuilder: () => ToastBuilder;

/**
 * NotificationBuilder to build NotificationStructure
 * @public
 * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare class NotificationBuilder {
    private title;
    private body;
    private createdAt;
    private logLevel;
    private alert;
    private toast;
    private banner;
    private snackbar;
    private dialog;
    /**
     * Add title to notification
     * @public
     * @param title - string
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withTitle(title: string): NotificationBuilder;
    /**
     * Add body details to notification
     * @public
     * @param body - string
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withBody(body: string): NotificationBuilder;
    /**
     * Add the creation date to notification
     * @public
     * @param createdAt - Date
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withCreatedAt(createdAt: Date): NotificationBuilder;
    /**
     * Add log level to notification
     * @public
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withLogLevel(logLevel: LogLevel): NotificationBuilder;
    /**
     * Add alert to notification
     * @public
     * @param alert - boolean
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withAlert(alert: boolean): NotificationBuilder;
    /**
     * Add toast to notification
     * @public
     * @param notification - {@link Toast}
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withToast(toast: Toast): NotificationBuilder;
    /**
     * Add banner to notification
     * @public
     * @param banner - {@link Banner}
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withBanner(banner: Banner): NotificationBuilder;
    /**
     * Add snackbar to notification
     * @public
     * @param snackbar - {@link Snackbar}
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withSnackbar(snackbar: Snackbar): NotificationBuilder;
    /**
     * Add dialog to notification
     * @public
     * @param dialog - {@link Dialog}
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withDialog(dialog: Dialog): NotificationBuilder;
    /**
     * Build NotificationStructure
     * @public
     * @returns
     * @deprecated Use showNotificationBanner/Dialog/Snackbar/Toast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    build(): NotificationStructure;
}

/**
 * Interface for notify data
 * @public
 */
export declare interface NotificationDataRow {
    ALERT_ID: string;
    CREATED_AT: number;
    DETAILS: {
        OPERATION: string;
        ROW_REF: string;
    };
    HEADER: string;
    MESSAGE: string;
    NOTIFY_SEVERITY: NotificationSeverity;
    EXPIRY?: number;
    SENDER?: null;
    USER_NAME: string;
    TABLE_ENTITY_ID: string;
    TOPIC: string;
}

/**
 * @internal
 */
export declare type NotificationElement = HTMLElement & {
    notification: NotificationStructure;
};

/**
 * @public
 * enum for different types of notification events
 */
export declare enum NotificationEvent {
    NOTIFICATION_EVENT = "notification-event"
}

/**
 * type for notification severity
 * @public
 */
export declare type NotificationSeverity = 'Information' | 'Warning' | 'Serious' | 'Critical';

/**
 * Interface for Notification Structure
 *  @public
 */
export declare interface NotificationStructure {
    readonly title?: string;
    readonly body: string;
    readonly createdAt?: Date;
    readonly logLevel?: LogLevel;
    readonly config?: {
        /**
         * @deprecated Use logLevel from the top level instead
         */
        readonly logLevel?: LogLevel;
        readonly alert?: boolean;
        readonly toast?: Toast;
        readonly banner?: Banner;
        readonly snackbar?: Snackbar;
        readonly dialog?: Dialog;
    };
}

/**
 * @public
 * type for notification
 */
export declare type NotificationType = 'error' | 'warning' | 'success';

/**
 * Shows the notificationStructure dialog
 * @public
 * @param notificationStructure - The NotificationStructure object
 * @param tagName - The tag name to create prefix for the design system provider & notificationStructure component
 * @param notificationBoundary - target listener for the notification
 * @returns
 * */
export declare const showBanner: (notificationStructure: NotificationStructure, tagName: String, notificationBoundary: HTMLElement) => void;

/**
 * Shows the dialog
 * @internal
 * @param notification - The NotificationStructure object
 * @param tagName - The tag name to create prefix for the design system provider & notification component
 * @returns
 * */
export declare const showDialog: (notificationStructure: NotificationStructure, tagName: String) => void;

/**
 * Shows logger with log level from NotificationStructure object
 * @public
 * @param notificationStructure - The NotificationStructure object
 */
export declare const showLoggerLogLevel: (notificationStructure: NotificationStructure) => void;

/**
 * Shows the notificationStructure in the appropriate component
 * @public
 * @param notificationStructure - The NotificationStructure object
 * @param tagName - The tag name to create prefix for the design system provider *
 * @param notificationBoundary - The notificationStructure boundary element
 * @returns
 * */
export declare const showNotification: (notificationStructure: NotificationStructure, tagName: String, notificationBoundary?: HTMLElement) => void;

/**
 * Shows the notification alert
 * @public
 */
export declare const showNotificationAlert: (configuration: AlertStructure) => void;

/**
 * Shows the notification banner
 * @public
 */
export declare const showNotificationBanner: (configuration: BannerStructure, tagName: String, notificationBoundary?: HTMLElement) => void;

/**
 * Shows the notification dialog
 * @public
 */
export declare const showNotificationDialog: (configuration: DialogStructure, tagName: String) => void;

/**
 * Shows the notification snackbar
 * @public
 */
export declare const showNotificationSnackbar: (configuration: SnackbarStructure, tagName: String) => void;

/**
 * Shows the notification toast
 * @public
 */
export declare const showNotificationToast: (configuration: ToastStructure, tagName: String, notificationContainer?: HTMLElement) => void;

/**
 * Shows the snackbar
 * @internal
 * @param notification - The NotificationStructure object
 * @param tagName - The tag name to create prefix for the design system provider & notification component
 * @returns
 * */
export declare const showSnackbar: (notificationStructure: NotificationStructure, tagName: String) => void;

/**
 * Shows the notificationStructure
 * @internal
 * @param notificationStructure - The NotificationStructure object
 * @param tagName - The tag name to create prefix for the design system provider & notificationStructure component
 * @param notificationContainer - The notificationStructure container element
 * @returns
 * */
export declare const showToast: (notificationStructure: NotificationStructure, tagName: String, notificationContainer?: HTMLElement) => void;

/**
 * Interface for Snackbar configuration
 * @public
 */
export declare interface Snackbar {
    readonly type?: SnackbarType;
    readonly confirmingActions?: Array<ConfirmingAction>;
}

/**
 * SnackbarBuilder to build Snackbar
 * @public
 * @deprecated Use showNotificationSnackbar instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare class SnackbarBuilder {
    private confirmingActions;
    private type;
    /**
     * @public
     * @param type - {@link SnackbarType}
     * @returns
     * @deprecated Use showNotificationSnackbar instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withType(type: SnackbarType): SnackbarBuilder;
    /**
     * Add confirming action to snackbar
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     * @deprecated Use showNotificationSnackbar instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withConfirmingAction(confirmingAction: ConfirmingAction): SnackbarBuilder;
    /**
     * Build snackbar
     * @public
     * @returns Snackbar
     * @deprecated Use showNotificationSnackbar instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    build(): Snackbar;
}

/**
 * Interface for Snackbar Structure
 *  @public
 */
export declare interface SnackbarStructure {
    readonly body: string;
    readonly logLevel?: LogLevel;
    readonly snackbar?: Snackbar;
}

/**
 * @public
 * type for snackbar type
 */
export declare type SnackbarType = 'error';

/**
 * Interface for Toast configuration
 * @public
 */
export declare interface Toast {
    readonly position?: ToastPosition;
    readonly type?: NotificationType;
    readonly autoClose?: boolean;
    readonly closeTimeout?: number;
    readonly details?: NotificationDataRow;
    readonly buttons?: ToastButton[];
}

/**
 * @public
 * @deprecated Use showNotificationToast instead or provide a NotificationStructure object when used with an event for a notification listener.
 */
export declare class ToastBuilder {
    private position;
    private autoClose;
    private closeTimeout;
    private type;
    private details;
    private buttons;
    /**
     * Add position to toast
     * @public
     * @param position - {@link ToastPosition}
     * @returns
     * @deprecated Use showNotificationToast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withPosition(position: ToastPosition): ToastBuilder;
    /**
     * Add auto close to notification
     * @public
     * @param autoClose - boolean
     * @returns
     * @deprecated Use showNotificationToast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withAutoClose(autoClose: boolean): ToastBuilder;
    /**
     * Add close timeout to notification
     * @public
     * @param closeTimeout - number
     * @returns
     * @deprecated Use showNotificationToast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withCloseTimeout(closeTimeout: number): ToastBuilder;
    /**
     * Add type to notification, if the type is anything other than 'warning' or 'success' do not add it
     * @public
     * @param type - {@link NotificationType}
     * @returns
     * @deprecated Use showNotificationToast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withType(type: NotificationType): ToastBuilder;
    /**
     * Add details data to notifications
     * @public
     * @param details - NotificationDataRow
     * @returns
     * @deprecated Use showNotificationToast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withDetails(details: NotificationDataRow): ToastBuilder;
    /**
     * Add buttons to notifications
     * @public
     * @param buttons - ToastButton[]
     * @returns
     * @deprecated Use showNotificationToast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    withButtons(buttons: ToastButton[]): ToastBuilder;
    /**
     * Build notification
     * @returns Toast
     * @deprecated Use showNotificationToast instead or provide a NotificationStructure object when used with an event for a notification listener.
     */
    build(): Toast;
}

/**
 * Interface for ToastButton
 * @public
 */
export declare interface ToastButton {
    action({ details, buttonElement, toastElement, }: {
        details: NotificationDataRow;
        buttonElement: HTMLElement;
        toastElement: any;
    }): void;
    condition({ details }?: {
        details: NotificationDataRow;
    }): boolean;
    placeholder?: string;
    appearance?: string;
}

/**
 * @public
 * type for notification position
 */
export declare type ToastPosition = 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';

/**
 * Interface for Toast Structure
 *  @public
 */
export declare interface ToastStructure {
    readonly title: string;
    readonly body: string;
    readonly createdAt?: Date;
    readonly logLevel?: LogLevel;
    readonly toast?: Toast;
}

export { }
